version 12.1

set more off, perm

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:  know.do												*;
*       Date:       July 30, 2016		                                *;
*       Authors:    Lisa Maria Dellmuth                                 *;
*       Purpose:    Replicate results for paper "The Knowledge Gap in   *;
*				  	World Politics"									    *;
*       Input File: know.dta  			                                *;
*       Machine:    Macbook Pro                                         *;	
*     ****************************************************************  *;
*     ****************************************************************  *;



*     ****************************************************************  *;
*	    Replicate Figure 1.						                        *;
*     ****************************************************************  *;

*For each value of country, use percentage of knowcat. 

forv i=0/2 {
        bys country : egen percent_`i'=mean(knowcat==`i') if sample==1
   } 
   
graph hbar percent_0 percent_1 percent_2 if sample==1, ///
	over(cname, sort(percent_0)) graphregion(color(white)) ///
	scheme(s2mono) stack legend(off) saving(figure1.gph, replace)

	
*     ****************************************************************  *;
*	    Replicate Table 1.						                        *;
*     ****************************************************************  *;
	
gllamm knowcat if sample==1, i(country) robust link(ologit) eform

eststo empty

esttab empty using table1.rtf, starlevels(* .05 ** .01) b(%9.2f) ///  
se(%9.2f) bic scalars(ll N) nodepvars replace 


*     ****************************************************************  *;
*       Replicate Table 2.												*;
*     ****************************************************************  *;

gllamm knowcat inc age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model1

gllamm knowcat inc solt_ginet incxsolt_ginet age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model2

gllamm knowcat identity age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model3

gllamm knowcat inc age gender secondary postsecon ///  
if sample==1, i(country) robust link(ologit) eform
eststo model4

gllamm knowcat inc solt_ginet incxsolt_ginet  age gender secondary postsecon /// 
if sample==1, i(country) robust link(ologit) eform
eststo model5

gllamm knowcat identity  age gender secondary postsecon ///
if sample==1, i(country) robust link(ologit) eform
eststo model6

gllamm knowcat inc age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model7

gllamm knowcat inc solt_ginet incxsolt_ginet age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model8

gllamm knowcat identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model9

gllamm knowcat inc solt_ginet incxsolt_ginet identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model10

esttab model1 model2 model3 model4 model5 model6 model7 model8 model9 model10 ///
using table2.rtf, starlevels(* .05 ** .01) b(%9.2f) eform se(%9.2f) bic scalars(ll N) nodepvars replace


*     ****************************************************************  *;
*	    Variance Inflation Factor and bivariate correlations.			*;
*     ****************************************************************  *;

collin inc solt_ginet identity age gender secondary postsecon /// 
jw_mdist ht_partsz gtm_parl gtm_unit

corr inc solt_ginet identity age gender secondary postsecon /// 
jw_mdist ht_partsz gtm_parl gtm_unit


*     ****************************************************************  *;
*       Robustness checks.												*;
*     ****************************************************************  *;

*With income as random coefficient.

generate cons = 1 
eq inter: cons
eq slope: inc

gllamm knowcat inc solt_ginet incxsolt_ginet age gender ///  
if sample==1, i(country) nrf(2) eqs(inter slope) robust link(ologit) eform
eststo model1_b3

gllamm knowcat inc solt_ginet incxsolt_ginet age gender secondary postsecon ///  
if sample==1, i(country) nrf(2) eqs(inter slope) robust link(ologit) eform
eststo model2_b3

gllamm knowcat inc solt_ginet incxsolt_ginet age gender secondary postsecon ///
jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) nrf(2) eqs(inter slope) robust link(ologit) eform
eststo model3_b3

gllamm knowcat inc solt_ginet incxsolt_ginet identity age gender secondary postsecon ///
jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) nrf(2) eqs(inter slope) robust link(ologit) eform
eststo model4_b3 

esttab model1_b3 model2_b3 model3_b3 model4_b3 using table_b3.rtf, ///
starlevels(* .05 ** .01) b(%9.2f) se(%9.2f) bic scalars(ll N) nodepvars eform replace


*With news media exposure.

gllamm knowcat unintnews inc age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model1_b4

gllamm knowcat unintnews inc solt_ginet incxsolt_ginet age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model2_b4

gllamm knowcat unintnews identity age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model3_b4

gllamm knowcat unintnews inc age gender secondary postsecon ///  
if sample==1, i(country) robust link(ologit) eform
eststo model4_b4

gllamm knowcat unintnews inc solt_ginet incxsolt_ginet  age gender secondary postsecon /// 
if sample==1, i(country) robust link(ologit) eform
eststo model5_b4

gllamm knowcat unintnews identity  age gender secondary postsecon ///
if sample==1, i(country) robust link(ologit) eform
eststo model6_b4

gllamm knowcat unintnews inc age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model7_b4

gllamm knowcat unintnews inc solt_ginet incxsolt_ginet age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model8_b4

gllamm knowcat unintnews identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model9_b4

gllamm knowcat unintnews inc solt_ginet incxsolt_ginet identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model10_b4

esttab model1_b4 model2_b4 model3_b4 model4_b4 model5_b4 model6_b4 model7_b4 model8_b4 model9_b4 model10_b4 ///
using table_b4.rtf, starlevels(* .05 ** .01) b(%9.2f) eform se(%9.2f) bic scalars(ll N) nodepvars replace


*Excluding party pluralism.

gllamm knowcat inc age gender secondary postsecon jw_mdist gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model1_b5

gllamm knowcat inc solt_ginet incxsolt_ginet age gender secondary postsecon jw_mdist gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model2_b5

gllamm knowcat identity age gender secondary postsecon jw_mdist gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model3_b5

gllamm knowcat inc solt_ginet incxsolt_ginet identity age gender secondary postsecon jw_mdist gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model4_b5

esttab model1_b5 model2_b5 model3_b5 model4_b5 using table_b5.rtf, ///
starlevels(* .05 ** .01) b(%9.2f) eform se(%9.2f) bic scalars(ll N) nodepvars replace


*With participation variable.

gllamm knowcat members inc age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model1_b6

gllamm knowcat members inc solt_ginet incxsolt_ginet age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model2_b6

gllamm knowcat members identity age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model3_b6

gllamm knowcat members inc age gender secondary postsecon ///  
if sample==1, i(country) robust link(ologit) eform
eststo model4_b6

gllamm knowcat members inc solt_ginet incxsolt_ginet  age gender secondary postsecon /// 
if sample==1, i(country) robust link(ologit) eform
eststo model5_b6

gllamm knowcat members identity  age gender secondary postsecon ///
if sample==1, i(country) robust link(ologit) eform
eststo model6_b6

gllamm knowcat members inc age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model7_b6

gllamm knowcat members inc solt_ginet incxsolt_ginet age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model8_b6

gllamm knowcat members identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model9_b6

gllamm knowcat members inc solt_ginet incxsolt_ginet identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model10_b6

esttab model1_b6 model2_b6 model3_b6 model4_b6 model5_b6 model6_b6 model7_b6 model8_b6 model9_b6 model10_b6 ///
using table_b6.rtf, starlevels(* .05 ** .01) b(%9.2f) eform se(%9.2f) bic scalars(ll N) nodepvars replace


*With exposure variable.

gllamm knowcat unscinvolvement inc age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model1_b7

gllamm knowcat unscinvolvement inc solt_ginet incxsolt_ginet age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model2_b7

gllamm knowcat unscinvolvement identity age gender ///  
if sample==1, i(country) robust link(ologit) eform
eststo model3_b7

gllamm knowcat unscinvolvement inc age gender secondary postsecon ///  
if sample==1, i(country) robust link(ologit) eform
eststo model4_b7

gllamm knowcat unscinvolvement inc solt_ginet incxsolt_ginet  age gender secondary postsecon /// 
if sample==1, i(country) robust link(ologit) eform
eststo model5_b7

gllamm knowcat unscinvolvement identity  age gender secondary postsecon ///
if sample==1, i(country) robust link(ologit) eform
eststo model6_b7

gllamm knowcat unscinvolvement inc age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model7_b7

gllamm knowcat unscinvolvement inc solt_ginet incxsolt_ginet age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model8_b7

gllamm knowcat unscinvolvement identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model9_b7

gllamm knowcat unscinvolvement inc solt_ginet incxsolt_ginet identity age gender secondary postsecon jw_mdist ht_partsz gtm_parl gtm_unit ///
if sample==1, i(country) robust link(ologit) eform
eststo model10_b7

esttab model1_b7 model2_b7 model3_b7 model4_b7 model5_b7 model6_b7 model7_b7 model8_b7 model9_b7 model10_b7 ///
using table_b7.rtf, starlevels(* .05 ** .01) b(%9.2f) eform se(%9.2f) bic scalars(ll N) nodepvars replace


